/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2026 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt6.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qabstractspinbox.sip"
#include <qabstractspinbox.h>
#line 29 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"

#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 36 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qtextstream.sip"
#include <qtextstream.h>
#line 41 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 806 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 44 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 47 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlineedit.sip"
#include <qlineedit.h>
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 325 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 53 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 56 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 254 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 754 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 62 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 339 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 65 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 297 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 68 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 353 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 74 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 239 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 77 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 788 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 213 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 283 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 24 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 89 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qvalidator.sip"
#include <qvalidator.h>
#line 92 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 95 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 98 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 101 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 104 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 107 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 113 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 116 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 119 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 122 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 125 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 128 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 131 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 134 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 137 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 140 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 145 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 143 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 146 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 149 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 30 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 152 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 155 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 158 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 161 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 164 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 167 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 380 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 170 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 444 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 173 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 497 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 176 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 466 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 179 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 483 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 182 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 555 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 185 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 807 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 188 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 269 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 191 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 742 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 194 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 50 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 197 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 110 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 200 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 203 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qaction.sip"
#include <qaction.h>
#line 206 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 209 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 212 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 215 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 218 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 221 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 224 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 227 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 230 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 154 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 235 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 238 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 277 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 241 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 244 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 28 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 247 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 135 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 250 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 253 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qanystringview.sip"
#include <qanystringview.h>
#line 256 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 25 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qflags.sip"
#include <qglobal.h>
#line 259 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 262 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"
#line 26 "/build/pyqt6/src/pyqt6-6.11.0/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 265 "/build/pyqt6/src/pyqt6-6.11.0/build/QtWidgets/sipQtWidgetsQAbstractSpinBox.cpp"


class sipQAbstractSpinBox : public ::QAbstractSpinBox
{
public:
    sipQAbstractSpinBox(::QWidget*);
    virtual ~sipQAbstractSpinBox();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void initStyleOption(::QStyleOptionSpinBox*) const SIP_OVERRIDE;
    ::QAbstractSpinBox::StepEnabled stepEnabled() const SIP_OVERRIDE;
    void clear() SIP_OVERRIDE;
    void stepBy(int) SIP_OVERRIDE;
    void fixup(::QString&) const SIP_OVERRIDE;
    ::QValidator::State validate(::QString&, int&) const SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEnterEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, ::qintptr*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQAbstractSpinBox(const sipQAbstractSpinBox &);
    sipQAbstractSpinBox &operator = (const sipQAbstractSpinBox &);

    char sipPyMethods[52];
};

sipQAbstractSpinBox::sipQAbstractSpinBox(::QWidget*a0): ::QAbstractSpinBox(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQAbstractSpinBox::~sipQAbstractSpinBox()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQAbstractSpinBox::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QAbstractSpinBox);

    return ::QAbstractSpinBox::metaObject();
}

int sipQAbstractSpinBox::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QAbstractSpinBox::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QAbstractSpinBox, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQAbstractSpinBox::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QAbstractSpinBox, _clname, &sipCpp) ? sipCpp : ::QAbstractSpinBox::qt_metacast(_clname));
}

void sipQAbstractSpinBox::initStyleOption(::QStyleOptionSpinBox*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initStyleOption);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::initStyleOption(a0);
        return;
    }

    extern void sipVH_QtWidgets_78(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QStyleOptionSpinBox*);

    sipVH_QtWidgets_78(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QAbstractSpinBox::StepEnabled sipQAbstractSpinBox::stepEnabled() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_stepEnabled);

    if (!sipMeth)
        return ::QAbstractSpinBox::stepEnabled();

    extern ::QAbstractSpinBox::StepEnabled sipVH_QtWidgets_77(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_77(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSpinBox::clear()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_clear);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::clear();
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSpinBox::stepBy(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_stepBy);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::stepBy(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::fixup(::QString& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_fixup);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::fixup(a0);
        return;
    }

    extern void sipVH_QtWidgets_76(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QString&);

    sipVH_QtWidgets_76(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QValidator::State sipQAbstractSpinBox::validate(::QString& a0, int& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_validate);

    if (!sipMeth)
        return ::QAbstractSpinBox::validate(a0, a1);

    extern ::QValidator::State sipVH_QtWidgets_75(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QString&, int&);

    return sipVH_QtWidgets_75(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQAbstractSpinBox::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSpinBox::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QAbstractSpinBox::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQAbstractSpinBox::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QAbstractSpinBox::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQAbstractSpinBox::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QAbstractSpinBox::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQAbstractSpinBox::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[14]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QAbstractSpinBox::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractSpinBox::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[15]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QAbstractSpinBox::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSpinBox::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQAbstractSpinBox::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[17]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QAbstractSpinBox::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQAbstractSpinBox::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[18]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QAbstractSpinBox::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQAbstractSpinBox::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[19]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QAbstractSpinBox::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::enterEvent(::QEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEnterEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[33], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[34], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[35], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[37], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQAbstractSpinBox::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQAbstractSpinBox::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[46]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QAbstractSpinBox::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSpinBox::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[47], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QAbstractSpinBox::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQAbstractSpinBox::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[48]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QAbstractSpinBox::hasHeightForWidth();

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQAbstractSpinBox::nativeEvent(const ::QByteArray& a0, void*a1, ::qintptr*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[49], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QAbstractSpinBox::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, ::qintptr*);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQAbstractSpinBox::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[50]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QAbstractSpinBox::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQAbstractSpinBox::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[51]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QAbstractSpinBox::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_36(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_36(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QAbstractSpinBox_buttonSymbols, "buttonSymbols(self) -> QAbstractSpinBox.ButtonSymbols");

extern "C" {static PyObject *meth_QAbstractSpinBox_buttonSymbols(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_buttonSymbols(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QAbstractSpinBox::ButtonSymbols sipRes;

            sipRes = sipCpp->buttonSymbols();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSpinBox_ButtonSymbols);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_buttonSymbols, doc_QAbstractSpinBox_buttonSymbols);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setButtonSymbols, "setButtonSymbols(self, bs: QAbstractSpinBox.ButtonSymbols)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setButtonSymbols(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setButtonSymbols(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox::ButtonSymbols a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QAbstractSpinBox_ButtonSymbols, &a0))
        {
            sipCpp->setButtonSymbols(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setButtonSymbols, doc_QAbstractSpinBox_setButtonSymbols);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_text, "text(self) -> str");

extern "C" {static PyObject *meth_QAbstractSpinBox_text(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_text, doc_QAbstractSpinBox_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_specialValueText, "specialValueText(self) -> str");

extern "C" {static PyObject *meth_QAbstractSpinBox_specialValueText(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_specialValueText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->specialValueText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_specialValueText, doc_QAbstractSpinBox_specialValueText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setSpecialValueText, "setSpecialValueText(self, s: str|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setSpecialValueText(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setSpecialValueText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setSpecialValueText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setSpecialValueText, doc_QAbstractSpinBox_setSpecialValueText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_wrapping, "wrapping(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_wrapping(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_wrapping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->wrapping();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_wrapping, doc_QAbstractSpinBox_wrapping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setWrapping, "setWrapping(self, w: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setWrapping(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setWrapping(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setWrapping(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setWrapping, doc_QAbstractSpinBox_setWrapping);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setReadOnly, "setReadOnly(self, r: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setReadOnly(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setReadOnly(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setReadOnly(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setReadOnly, doc_QAbstractSpinBox_setReadOnly);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_isReadOnly, "isReadOnly(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_isReadOnly(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_isReadOnly(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isReadOnly();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_isReadOnly, doc_QAbstractSpinBox_isReadOnly);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setAlignment, "setAlignment(self, flag: Qt.AlignmentFlag)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setAlignment(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setAlignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::Alignment* a0;
        int a0State = 0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QFlags_0100Qt_AlignmentFlag, &a0, &a0State))
        {
            sipCpp->setAlignment(*a0);
            sipReleaseType(a0, sipType_QFlags_0100Qt_AlignmentFlag, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setAlignment, doc_QAbstractSpinBox_setAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_alignment, "alignment(self) -> Qt.AlignmentFlag");

extern "C" {static PyObject *meth_QAbstractSpinBox_alignment(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_alignment(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::Qt::Alignment*sipRes;

            sipRes = new ::Qt::Alignment(sipCpp->alignment());

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100Qt_AlignmentFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_alignment, doc_QAbstractSpinBox_alignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setFrame, "setFrame(self, a0: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setFrame(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setFrame(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setFrame, doc_QAbstractSpinBox_setFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_hasFrame, "hasFrame(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_hasFrame(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_hasFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasFrame();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_hasFrame, doc_QAbstractSpinBox_hasFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_sizeHint, "sizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractSpinBox_sizeHint(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_sizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QAbstractSpinBox::sizeHint() : sipCpp->sizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_sizeHint, doc_QAbstractSpinBox_sizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_minimumSizeHint, "minimumSizeHint(self) -> QSize");

extern "C" {static PyObject *meth_QAbstractSpinBox_minimumSizeHint(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_minimumSizeHint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize((sipSelfWasArg ? sipCpp->::QAbstractSpinBox::minimumSizeHint() : sipCpp->minimumSizeHint()));

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_minimumSizeHint, doc_QAbstractSpinBox_minimumSizeHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_interpretText, "interpretText(self)");

extern "C" {static PyObject *meth_QAbstractSpinBox_interpretText(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_interpretText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            sipCpp->interpretText();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_interpretText, doc_QAbstractSpinBox_interpretText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_event, "event(self, event: QEvent|None) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_event(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_event, doc_QAbstractSpinBox_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_validate, "validate(self, input: str|None, pos: int) -> (QValidator.State, str, int)");

extern "C" {static PyObject *meth_QAbstractSpinBox_validate(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_validate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QString* a0;
        int a0State = 0;
        int a1;
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1i", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QString, &a0, &a0State, &a1))
        {
            ::QValidator::State sipRes;
            PyObject *sipResObj;

            sipRes = (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::validate(*a0, a1) : sipCpp->validate(*a0, a1));

            sipResObj = sipBuildResult(0, "(FDi)", sipRes, sipType_QValidator_State, a0, sipType_QString, SIP_NULLPTR, a1);
            sipReleaseType(a0, sipType_QString, a0State);

            return sipResObj;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_validate, doc_QAbstractSpinBox_validate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_fixup, "fixup(self, input: str|None) -> str");

extern "C" {static PyObject *meth_QAbstractSpinBox_fixup(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_fixup(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QString* a0;
        int a0State = 0;
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QString, &a0, &a0State))
        {
            PyObject *sipResObj;

            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::fixup(*a0) : sipCpp->fixup(*a0));

            sipResObj = sipConvertFromType(a0, sipType_QString, SIP_NULLPTR);
            sipReleaseType(a0, sipType_QString, a0State);

            return sipResObj;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_fixup, doc_QAbstractSpinBox_fixup);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_stepBy, "stepBy(self, steps: int)");

extern "C" {static PyObject *meth_QAbstractSpinBox_stepBy(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_stepBy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        int a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::stepBy(a0) : sipCpp->stepBy(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_stepBy, doc_QAbstractSpinBox_stepBy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_stepUp, "stepUp(self)");

extern "C" {static PyObject *meth_QAbstractSpinBox_stepUp(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_stepUp(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            sipCpp->stepUp();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_stepUp, doc_QAbstractSpinBox_stepUp);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_stepDown, "stepDown(self)");

extern "C" {static PyObject *meth_QAbstractSpinBox_stepDown(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_stepDown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            sipCpp->stepDown();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_stepDown, doc_QAbstractSpinBox_stepDown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_selectAll, "selectAll(self)");

extern "C" {static PyObject *meth_QAbstractSpinBox_selectAll(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_selectAll(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            sipCpp->selectAll();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_selectAll, doc_QAbstractSpinBox_selectAll);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_clear, "clear(self)");

extern "C" {static PyObject *meth_QAbstractSpinBox_clear(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::clear() : sipCpp->clear());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_clear, doc_QAbstractSpinBox_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_resizeEvent, "resizeEvent(self, e: QResizeEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_resizeEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_resizeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QResizeEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QResizeEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::resizeEvent(a0) : sipCpp->resizeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_resizeEvent, doc_QAbstractSpinBox_resizeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_keyPressEvent, "keyPressEvent(self, e: QKeyEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_keyPressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_keyPressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::keyPressEvent(a0) : sipCpp->keyPressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_keyPressEvent, doc_QAbstractSpinBox_keyPressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_keyReleaseEvent, "keyReleaseEvent(self, e: QKeyEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_keyReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_keyReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QKeyEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QKeyEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::keyReleaseEvent(a0) : sipCpp->keyReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_keyReleaseEvent, doc_QAbstractSpinBox_keyReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_wheelEvent, "wheelEvent(self, e: QWheelEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_wheelEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_wheelEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWheelEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QWheelEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::wheelEvent(a0) : sipCpp->wheelEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_wheelEvent, doc_QAbstractSpinBox_wheelEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_focusInEvent, "focusInEvent(self, e: QFocusEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_focusInEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_focusInEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::focusInEvent(a0) : sipCpp->focusInEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_focusInEvent, doc_QAbstractSpinBox_focusInEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_focusOutEvent, "focusOutEvent(self, e: QFocusEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_focusOutEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_focusOutEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QFocusEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QFocusEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::focusOutEvent(a0) : sipCpp->focusOutEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_focusOutEvent, doc_QAbstractSpinBox_focusOutEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_contextMenuEvent, "contextMenuEvent(self, e: QContextMenuEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_contextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_contextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QContextMenuEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::contextMenuEvent(a0) : sipCpp->contextMenuEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_contextMenuEvent, doc_QAbstractSpinBox_contextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_changeEvent, "changeEvent(self, e: QEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_changeEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_changeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::changeEvent(a0) : sipCpp->changeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_changeEvent, doc_QAbstractSpinBox_changeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_closeEvent, "closeEvent(self, e: QCloseEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_closeEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_closeEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QCloseEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QCloseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::closeEvent(a0) : sipCpp->closeEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_closeEvent, doc_QAbstractSpinBox_closeEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_hideEvent, "hideEvent(self, e: QHideEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_hideEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_hideEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QHideEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QHideEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::hideEvent(a0) : sipCpp->hideEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_hideEvent, doc_QAbstractSpinBox_hideEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_mousePressEvent, "mousePressEvent(self, e: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_mousePressEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_mousePressEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::mousePressEvent(a0) : sipCpp->mousePressEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_mousePressEvent, doc_QAbstractSpinBox_mousePressEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_mouseReleaseEvent, "mouseReleaseEvent(self, e: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_mouseReleaseEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_mouseReleaseEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::mouseReleaseEvent(a0) : sipCpp->mouseReleaseEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_mouseReleaseEvent, doc_QAbstractSpinBox_mouseReleaseEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_mouseMoveEvent, "mouseMoveEvent(self, e: QMouseEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_mouseMoveEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_mouseMoveEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QMouseEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QMouseEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::mouseMoveEvent(a0) : sipCpp->mouseMoveEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_mouseMoveEvent, doc_QAbstractSpinBox_mouseMoveEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_timerEvent, "timerEvent(self, e: QTimerEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_timerEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_timerEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTimerEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QTimerEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::timerEvent(a0) : sipCpp->timerEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_timerEvent, doc_QAbstractSpinBox_timerEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_paintEvent, "paintEvent(self, e: QPaintEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_paintEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_paintEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QPaintEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QPaintEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::paintEvent(a0) : sipCpp->paintEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_paintEvent, doc_QAbstractSpinBox_paintEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_showEvent, "showEvent(self, e: QShowEvent|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_showEvent(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_showEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QShowEvent* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QShowEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::showEvent(a0) : sipCpp->showEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_showEvent, doc_QAbstractSpinBox_showEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_lineEdit, "lineEdit(self) -> QLineEdit|None");

extern "C" {static PyObject *meth_QAbstractSpinBox_lineEdit(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_lineEdit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QLineEdit*sipRes;

            sipRes = sipCpp->lineEdit();

            return sipConvertFromType(sipRes, sipType_QLineEdit, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_lineEdit, doc_QAbstractSpinBox_lineEdit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setLineEdit, "setLineEdit(self, e: QLineEdit|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setLineEdit(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setLineEdit(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QLineEdit* a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ:", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QLineEdit, &a0))
        {
            sipCpp->setLineEdit(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setLineEdit, doc_QAbstractSpinBox_setLineEdit);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_stepEnabled, "stepEnabled(self) -> QAbstractSpinBox.StepEnabledFlag");

extern "C" {static PyObject *meth_QAbstractSpinBox_stepEnabled(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_stepEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QAbstractSpinBox::StepEnabled*sipRes;

            sipRes = new ::QAbstractSpinBox::StepEnabled((sipSelfWasArg ? sipCpp->::QAbstractSpinBox::stepEnabled() : sipCpp->stepEnabled()));

            return sipConvertFromNewType(sipRes, sipType_QFlags_0100QAbstractSpinBox_StepEnabledFlag, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_stepEnabled, doc_QAbstractSpinBox_stepEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_initStyleOption, "initStyleOption(self, option: QStyleOptionSpinBox|None)");

extern "C" {static PyObject *meth_QAbstractSpinBox_initStyleOption(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_initStyleOption(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QStyleOptionSpinBox* a0;
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QStyleOptionSpinBox, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractSpinBox::initStyleOption(a0) : sipCpp->initStyleOption(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_initStyleOption, doc_QAbstractSpinBox_initStyleOption);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setCorrectionMode, "setCorrectionMode(self, cm: QAbstractSpinBox.CorrectionMode)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setCorrectionMode(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setCorrectionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractSpinBox::CorrectionMode a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_QAbstractSpinBox_CorrectionMode, &a0))
        {
            sipCpp->setCorrectionMode(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setCorrectionMode, doc_QAbstractSpinBox_setCorrectionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_correctionMode, "correctionMode(self) -> QAbstractSpinBox.CorrectionMode");

extern "C" {static PyObject *meth_QAbstractSpinBox_correctionMode(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_correctionMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            ::QAbstractSpinBox::CorrectionMode sipRes;

            sipRes = sipCpp->correctionMode();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractSpinBox_CorrectionMode);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_correctionMode, doc_QAbstractSpinBox_correctionMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_hasAcceptableInput, "hasAcceptableInput(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_hasAcceptableInput(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_hasAcceptableInput(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasAcceptableInput();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_hasAcceptableInput, doc_QAbstractSpinBox_hasAcceptableInput);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setAccelerated, "setAccelerated(self, on: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setAccelerated(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setAccelerated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setAccelerated(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setAccelerated, doc_QAbstractSpinBox_setAccelerated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_isAccelerated, "isAccelerated(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_isAccelerated(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_isAccelerated(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAccelerated();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_isAccelerated, doc_QAbstractSpinBox_isAccelerated);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setKeyboardTracking, "setKeyboardTracking(self, kt: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setKeyboardTracking(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setKeyboardTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setKeyboardTracking(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setKeyboardTracking, doc_QAbstractSpinBox_setKeyboardTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_keyboardTracking, "keyboardTracking(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_keyboardTracking(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_keyboardTracking(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->keyboardTracking();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_keyboardTracking, doc_QAbstractSpinBox_keyboardTracking);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_inputMethodQuery, "inputMethodQuery(self, a0: Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QAbstractSpinBox_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QAbstractSpinBox)) || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::Qt::InputMethodQuery a0;
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant((sipSelfWasArg ? sipCpp->::QAbstractSpinBox::inputMethodQuery(a0) : sipCpp->inputMethodQuery(a0)));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_inputMethodQuery, doc_QAbstractSpinBox_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_setGroupSeparatorShown, "setGroupSeparatorShown(self, shown: bool)");

extern "C" {static PyObject *meth_QAbstractSpinBox_setGroupSeparatorShown(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_setGroupSeparatorShown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QAbstractSpinBox, &sipCpp, &a0))
        {
            sipCpp->setGroupSeparatorShown(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_setGroupSeparatorShown, doc_QAbstractSpinBox_setGroupSeparatorShown);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractSpinBox_isGroupSeparatorShown, "isGroupSeparatorShown(self) -> bool");

extern "C" {static PyObject *meth_QAbstractSpinBox_isGroupSeparatorShown(PyObject *, PyObject *);}
static PyObject *meth_QAbstractSpinBox_isGroupSeparatorShown(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractSpinBox *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractSpinBox, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isGroupSeparatorShown();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractSpinBox, sipName_isGroupSeparatorShown, doc_QAbstractSpinBox_isGroupSeparatorShown);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractSpinBox(void *, const sipTypeDef *);}
static void *cast_QAbstractSpinBox(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstractSpinBox *sipCpp = reinterpret_cast< ::QAbstractSpinBox *>(sipCppV);

    if (targetType == sipType_QAbstractSpinBox)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QWidget)->ctd_cast(static_cast< ::QWidget *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractSpinBox(void *, int);}
static void release_QAbstractSpinBox(void *sipCppV, int)
{
    ::QAbstractSpinBox *sipCpp = reinterpret_cast< ::QAbstractSpinBox *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QAbstractSpinBox(Py_ssize_t);}
static void *array_QAbstractSpinBox(Py_ssize_t sipNrElem)
{
    return new ::QAbstractSpinBox[sipNrElem];
}


extern "C" {static void array_delete_QAbstractSpinBox(void *);}
static void array_delete_QAbstractSpinBox(void *sipCpp)
{
    delete[] reinterpret_cast< ::QAbstractSpinBox *>(sipCpp);
}


extern "C" {static void dealloc_QAbstractSpinBox(sipSimpleWrapper *);}
static void dealloc_QAbstractSpinBox(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQAbstractSpinBox *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractSpinBox(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QAbstractSpinBox(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QAbstractSpinBox(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQAbstractSpinBox *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQAbstractSpinBox(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractSpinBox[] = {{444, 255, 1}};


static PyMethodDef methods_QAbstractSpinBox[] = {
    {sipName_alignment, meth_QAbstractSpinBox_alignment, METH_VARARGS, doc_QAbstractSpinBox_alignment},
    {sipName_buttonSymbols, meth_QAbstractSpinBox_buttonSymbols, METH_VARARGS, doc_QAbstractSpinBox_buttonSymbols},
    {sipName_changeEvent, meth_QAbstractSpinBox_changeEvent, METH_VARARGS, doc_QAbstractSpinBox_changeEvent},
    {sipName_clear, meth_QAbstractSpinBox_clear, METH_VARARGS, doc_QAbstractSpinBox_clear},
    {sipName_closeEvent, meth_QAbstractSpinBox_closeEvent, METH_VARARGS, doc_QAbstractSpinBox_closeEvent},
    {sipName_contextMenuEvent, meth_QAbstractSpinBox_contextMenuEvent, METH_VARARGS, doc_QAbstractSpinBox_contextMenuEvent},
    {sipName_correctionMode, meth_QAbstractSpinBox_correctionMode, METH_VARARGS, doc_QAbstractSpinBox_correctionMode},
    {sipName_event, meth_QAbstractSpinBox_event, METH_VARARGS, doc_QAbstractSpinBox_event},
    {sipName_fixup, meth_QAbstractSpinBox_fixup, METH_VARARGS, doc_QAbstractSpinBox_fixup},
    {sipName_focusInEvent, meth_QAbstractSpinBox_focusInEvent, METH_VARARGS, doc_QAbstractSpinBox_focusInEvent},
    {sipName_focusOutEvent, meth_QAbstractSpinBox_focusOutEvent, METH_VARARGS, doc_QAbstractSpinBox_focusOutEvent},
    {sipName_hasAcceptableInput, meth_QAbstractSpinBox_hasAcceptableInput, METH_VARARGS, doc_QAbstractSpinBox_hasAcceptableInput},
    {sipName_hasFrame, meth_QAbstractSpinBox_hasFrame, METH_VARARGS, doc_QAbstractSpinBox_hasFrame},
    {sipName_hideEvent, meth_QAbstractSpinBox_hideEvent, METH_VARARGS, doc_QAbstractSpinBox_hideEvent},
    {sipName_initStyleOption, meth_QAbstractSpinBox_initStyleOption, METH_VARARGS, doc_QAbstractSpinBox_initStyleOption},
    {sipName_inputMethodQuery, meth_QAbstractSpinBox_inputMethodQuery, METH_VARARGS, doc_QAbstractSpinBox_inputMethodQuery},
    {sipName_interpretText, meth_QAbstractSpinBox_interpretText, METH_VARARGS, doc_QAbstractSpinBox_interpretText},
    {sipName_isAccelerated, meth_QAbstractSpinBox_isAccelerated, METH_VARARGS, doc_QAbstractSpinBox_isAccelerated},
    {sipName_isGroupSeparatorShown, meth_QAbstractSpinBox_isGroupSeparatorShown, METH_VARARGS, doc_QAbstractSpinBox_isGroupSeparatorShown},
    {sipName_isReadOnly, meth_QAbstractSpinBox_isReadOnly, METH_VARARGS, doc_QAbstractSpinBox_isReadOnly},
    {sipName_keyPressEvent, meth_QAbstractSpinBox_keyPressEvent, METH_VARARGS, doc_QAbstractSpinBox_keyPressEvent},
    {sipName_keyReleaseEvent, meth_QAbstractSpinBox_keyReleaseEvent, METH_VARARGS, doc_QAbstractSpinBox_keyReleaseEvent},
    {sipName_keyboardTracking, meth_QAbstractSpinBox_keyboardTracking, METH_VARARGS, doc_QAbstractSpinBox_keyboardTracking},
    {sipName_lineEdit, meth_QAbstractSpinBox_lineEdit, METH_VARARGS, doc_QAbstractSpinBox_lineEdit},
    {sipName_minimumSizeHint, meth_QAbstractSpinBox_minimumSizeHint, METH_VARARGS, doc_QAbstractSpinBox_minimumSizeHint},
    {sipName_mouseMoveEvent, meth_QAbstractSpinBox_mouseMoveEvent, METH_VARARGS, doc_QAbstractSpinBox_mouseMoveEvent},
    {sipName_mousePressEvent, meth_QAbstractSpinBox_mousePressEvent, METH_VARARGS, doc_QAbstractSpinBox_mousePressEvent},
    {sipName_mouseReleaseEvent, meth_QAbstractSpinBox_mouseReleaseEvent, METH_VARARGS, doc_QAbstractSpinBox_mouseReleaseEvent},
    {sipName_paintEvent, meth_QAbstractSpinBox_paintEvent, METH_VARARGS, doc_QAbstractSpinBox_paintEvent},
    {sipName_resizeEvent, meth_QAbstractSpinBox_resizeEvent, METH_VARARGS, doc_QAbstractSpinBox_resizeEvent},
    {sipName_selectAll, meth_QAbstractSpinBox_selectAll, METH_VARARGS, doc_QAbstractSpinBox_selectAll},
    {sipName_setAccelerated, meth_QAbstractSpinBox_setAccelerated, METH_VARARGS, doc_QAbstractSpinBox_setAccelerated},
    {sipName_setAlignment, meth_QAbstractSpinBox_setAlignment, METH_VARARGS, doc_QAbstractSpinBox_setAlignment},
    {sipName_setButtonSymbols, meth_QAbstractSpinBox_setButtonSymbols, METH_VARARGS, doc_QAbstractSpinBox_setButtonSymbols},
    {sipName_setCorrectionMode, meth_QAbstractSpinBox_setCorrectionMode, METH_VARARGS, doc_QAbstractSpinBox_setCorrectionMode},
    {sipName_setFrame, meth_QAbstractSpinBox_setFrame, METH_VARARGS, doc_QAbstractSpinBox_setFrame},
    {sipName_setGroupSeparatorShown, meth_QAbstractSpinBox_setGroupSeparatorShown, METH_VARARGS, doc_QAbstractSpinBox_setGroupSeparatorShown},
    {sipName_setKeyboardTracking, meth_QAbstractSpinBox_setKeyboardTracking, METH_VARARGS, doc_QAbstractSpinBox_setKeyboardTracking},
    {sipName_setLineEdit, meth_QAbstractSpinBox_setLineEdit, METH_VARARGS, doc_QAbstractSpinBox_setLineEdit},
    {sipName_setReadOnly, meth_QAbstractSpinBox_setReadOnly, METH_VARARGS, doc_QAbstractSpinBox_setReadOnly},
    {sipName_setSpecialValueText, meth_QAbstractSpinBox_setSpecialValueText, METH_VARARGS, doc_QAbstractSpinBox_setSpecialValueText},
    {sipName_setWrapping, meth_QAbstractSpinBox_setWrapping, METH_VARARGS, doc_QAbstractSpinBox_setWrapping},
    {sipName_showEvent, meth_QAbstractSpinBox_showEvent, METH_VARARGS, doc_QAbstractSpinBox_showEvent},
    {sipName_sizeHint, meth_QAbstractSpinBox_sizeHint, METH_VARARGS, doc_QAbstractSpinBox_sizeHint},
    {sipName_specialValueText, meth_QAbstractSpinBox_specialValueText, METH_VARARGS, doc_QAbstractSpinBox_specialValueText},
    {sipName_stepBy, meth_QAbstractSpinBox_stepBy, METH_VARARGS, doc_QAbstractSpinBox_stepBy},
    {sipName_stepDown, meth_QAbstractSpinBox_stepDown, METH_VARARGS, doc_QAbstractSpinBox_stepDown},
    {sipName_stepEnabled, meth_QAbstractSpinBox_stepEnabled, METH_VARARGS, doc_QAbstractSpinBox_stepEnabled},
    {sipName_stepUp, meth_QAbstractSpinBox_stepUp, METH_VARARGS, doc_QAbstractSpinBox_stepUp},
    {sipName_text, meth_QAbstractSpinBox_text, METH_VARARGS, doc_QAbstractSpinBox_text},
    {sipName_timerEvent, meth_QAbstractSpinBox_timerEvent, METH_VARARGS, doc_QAbstractSpinBox_timerEvent},
    {sipName_validate, meth_QAbstractSpinBox_validate, METH_VARARGS, doc_QAbstractSpinBox_validate},
    {sipName_wheelEvent, meth_QAbstractSpinBox_wheelEvent, METH_VARARGS, doc_QAbstractSpinBox_wheelEvent},
    {sipName_wrapping, meth_QAbstractSpinBox_wrapping, METH_VARARGS, doc_QAbstractSpinBox_wrapping}
};


/* Define the enum members and ints to be added to this type. */
static sipIntInstanceDef intInstances_QAbstractSpinBox[] = {
    {sipName_UpDownArrows, static_cast<int>(::QAbstractSpinBox::UpDownArrows)},
    {sipName_PlusMinus, static_cast<int>(::QAbstractSpinBox::PlusMinus)},
    {sipName_NoButtons, static_cast<int>(::QAbstractSpinBox::NoButtons)},
    {sipName_CorrectToPreviousValue, static_cast<int>(::QAbstractSpinBox::CorrectToPreviousValue)},
    {sipName_CorrectToNearestValue, static_cast<int>(::QAbstractSpinBox::CorrectToNearestValue)},
    {sipName_StepNone, static_cast<int>(::QAbstractSpinBox::StepNone)},
    {sipName_StepUpEnabled, static_cast<int>(::QAbstractSpinBox::StepUpEnabled)},
    {sipName_StepDownEnabled, static_cast<int>(::QAbstractSpinBox::StepDownEnabled)},
    {sipName_DefaultStepType, static_cast<int>(::QAbstractSpinBox::DefaultStepType)},
    {sipName_AdaptiveDecimalStepType, static_cast<int>(::QAbstractSpinBox::AdaptiveDecimalStepType)},
    {0, 0}
};

PyDoc_STRVAR(doc_QAbstractSpinBox, "\1QAbstractSpinBox(parent: QWidget|None = None)");


/* Define this type's signals. */
static const pyqt6QtSignal signals_QAbstractSpinBox[] = {
    {"returnPressed()", "\1returnPressed(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"editingFinished()", "\1editingFinished(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt6ClassPluginDef plugin_QAbstractSpinBox = {
    &::QAbstractSpinBox::staticMetaObject,
    signals_QAbstractSpinBox,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QAbstractSpinBox = {
    {
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractSpinBox,
        SIP_NULLPTR,
        &plugin_QAbstractSpinBox,
    },
    {
        sipNameNr_QAbstractSpinBox,
        {0, 0, 1},
        54, methods_QAbstractSpinBox,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, intInstances_QAbstractSpinBox, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QAbstractSpinBox,
    -1,
    -1,
    supers_QAbstractSpinBox,
    SIP_NULLPTR,
    init_type_QAbstractSpinBox,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractSpinBox,
    SIP_NULLPTR,
    array_QAbstractSpinBox,
    SIP_NULLPTR,
    release_QAbstractSpinBox,
    cast_QAbstractSpinBox,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QAbstractSpinBox,
    sizeof (::QAbstractSpinBox),
};
